from ..span import SpanContext
from .propagator import Propagator

class BinaryPropagator(Propagator):
    def inject(self, span_context: SpanContext, carrier) -> None: ...
    def extract(self, carrier): ...
