from typing import Any

from .tracer import Tracer

class SpanContext:
    EMPTY_BAGGAGE: Any
    @property
    def baggage(self): ...

class Span:
    def __init__(self, tracer: Tracer, context: SpanContext) -> None: ...
    @property
    def context(self): ...
    @property
    def tracer(self) -> Tracer: ...
    def set_operation_name(self, operation_name: str): ...
    def finish(self, finish_time=...) -> None: ...
    def set_tag(self, key, value): ...
    def log_kv(self, key_values, timestamp=...): ...
    def set_baggage_item(self, key, value): ...
    def get_baggage_item(self, key) -> None: ...
    def __enter__(self): ...
    def __exit__(self, exc_type, exc_val, exc_tb) -> None: ...
    def log_event(self, event, payload=...): ...
    def log(self, **kwargs): ...
